@@ -476,10 +476,9 @@ class Distributive(object):
         """
         newDirectoryName = directory
         for i in range(2, 9999):
-            try:
-                os.mkdir(newDirectoryName)
+            if not path.exists(newDirectoryName):
                 return newDirectoryName
-            except OSError:
+            else:
                 newDirectoryName = "%s.%02d" % (directory, i)
         return newDirectoryName
 
@@ -1411,7 +1410,7 @@ class SquashDistributive(Distributive):
             cmd += ["-e"] + self.exclude
         # возможность использовать заранее подготовленный livecd.squashfs
         if path.exists('/var/calculate/tmp/livecd.squashfs'):
-            os.system('cp /var/calculate/tmp/livecd.squashfs %s' % file)
+            os.system('cp -L /var/calculate/tmp/livecd.squashfs %s' % file)
         else:
             callbackProgress = kwargs.get('callbackProgress', None)
             processMkSquash = PercentProgress(*cmd, stderr=STDOUT, atty=True)
