@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2008-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -33,7 +33,9 @@ import fcntl
 import struct
 
 from calculate.lib.cl_lang import setLocalTranslate, _
-setLocalTranslate('cl_install3',sys.modules[__name__])
+
+setLocalTranslate('cl_install3', sys.modules[__name__])
+
 
 class VideoVariable(Variable):
     """
@@ -47,7 +49,7 @@ class VideoVariable(Variable):
                     'radeon': _("ATI open source video driver"),
                     'nouveau': _("NVidia open source video driver"),
                     'default': _("X.Org Server auto detection")
-    }
+                    }
 
     def uncompatible(self):
         """
@@ -61,6 +63,7 @@ class VideoVariable(Variable):
                 _("This distribution does not provide a Xorg server")
         return ""
 
+
 class ResolutionVariable(VideoVariable):
     """
     Abstract resolution variable
@@ -76,20 +79,21 @@ class ResolutionVariable(VideoVariable):
                        "1600x900", "1600x1200", "2048x1152", "2560x1440",
                        "2560x1600"]
         if self.fbres:
-            return map(lambda x:"%s-32"%x,
-                   resolutions)
+            return map(lambda x: "%s-32" % x,
+                       resolutions)
         else:
             return resolutions
 
-    def check(self,value):
+    def check(self, value):
         """
         Check resolution format 1234x567
         """
-        if not re.match('^\d+x\d+(-\d+(@\d+)?)?$',value):
+        if not re.match('^\d+x\d+(-\d+(@\d+)?)?$', value):
             raise VariableError(
                 _("Wrong resolution {resolution} {example}").format(
-                resolution=value,
-                example="(%s:%s)"%(_("Example"),"1024x768")))
+                    resolution=value,
+                    example="(%s:%s)" % (_("Example"), "1024x768")))
+
 
 class VariableOsInstallX11Resolution(ResolutionVariable):
     """
@@ -109,11 +113,12 @@ class VariableOsInstallX11Resolution(ResolutionVariable):
     def get(self):
         # get resolution from xorg.log
         res = self.Get('os_x11_resolution')
-        if res or self.Get('os_install_root_type') in ('livecd','usb-hdd'):
+        if res or self.Get('os_install_root_type') in ('livecd', 'usb-hdd'):
             return res or self.fallback_resolution
         else:
             return self.fallback_resolution
 
+
 class VariableOsInstallX11VideoAvailable(VideoVariable):
     """
     Get available (already installed or installable drivers
@@ -124,14 +129,15 @@ class VariableOsInstallX11VideoAvailable(VideoVariable):
     def get(self):
         image = self.Get('cl_image')
         if image:
-            with image as distr:
+            with image:
                 try:
                     distrPath = image.getDirectory()
-                    if isPkgInstalled('xorg-server',prefix=distrPath):
+                    if isPkgInstalled('xorg-server', prefix=distrPath):
                         return (sorted(filter(self.supported.__contains__,
-                                getAvailableVideo(prefix=distrPath))) +
+                                              getAvailableVideo(
+                                                  prefix=distrPath))) +
                                 [self.default_video])
-                except DistributiveError as e:
+                except DistributiveError:
                     pass
         return []
 
@@ -175,52 +181,55 @@ class VariableOsInstallX11VideoDrv(VideoVariable):
                 return self.default_video
             # if type system is usb-hdd then get detect video driver
             if self.Get('os_install_root_type') == 'usb-hdd':
-                methods = ((getVideoFromModules,()),
-                           (getVideoFromCmdLine,()),
-                           (getVideoFromVendor,(self.Get('hr_video'),list_video)))
+                methods = ((getVideoFromModules, ()),
+                           (getVideoFromCmdLine, ()),
+                           (getVideoFromVendor,
+                            (self.Get('hr_video'), list_video)))
             else:
                 # test current video driver for install system
-                methods = ((getVideoFromXorgLog,('/',list_video)),
-                           (getVideoFromXorgConf,('/',)),
-                           (getVideoFromModules,()),
-                           (getVideoFromCmdLine,()),
-                           (getVideoFromVendor,(self.Get('hr_video'),list_video)))
-            for func,args in methods:
+                methods = ((getVideoFromXorgLog, ('/', list_video)),
+                           (getVideoFromXorgConf, ('/',)),
+                           (getVideoFromModules, ()),
+                           (getVideoFromCmdLine, ()),
+                           (getVideoFromVendor,
+                            (self.Get('hr_video'), list_video)))
+            for func, args in methods:
                 drv = func(*args)
                 if drv in list_video:
                     return drv
             return self.default_video
         else:
-            for drv in map(lambda x:x[0], self.choice()):
-                videoSysPath = path.join("/sys/module",drv,"refcnt")
+            for drv in map(lambda x: x[0], self.choice()):
+                videoSysPath = path.join("/sys/module", drv, "refcnt")
                 refcnt = readFile(videoSysPath).strip()
                 if refcnt.isdigit() and int(refcnt) > 0:
-                    return {'i915':'intel'}.get(drv,drv)
+                    return {'i915': 'intel'}.get(drv, drv)
             else:
                 return self.default_video
 
-    pkgDrvMap = {'nvidia':('NVidia','x11-drivers/nvidia-drivers'),
-                 'fglrx':('ATI','x11-drivers/ati-drivers'),
-                 'vboxdrv':('VirtualBox','x11-drivers/xf86-video-virtualbox')}
+    pkgDrvMap = {'nvidia': ('NVidia', 'x11-drivers/nvidia-drivers'),
+                 'fglrx': ('ATI', 'x11-drivers/ati-drivers'),
+                 'vboxdrv': ('VirtualBox', 'x11-drivers/xf86-video-virtualbox')}
 
-    def check(self,value):
+    def check(self, value):
         if self.Get('os_install_x11_server_set') == 'on':
             if self.Get('cl_action') == 'system':
                 availDrvs = self.Get('os_install_x11_video_available')
                 if not value in availDrvs:
-                    raise VariableError(_("Only %s drivers are available")%
-                            ",".join(availDrvs))
+                    raise VariableError(_("Only %s drivers are available") %
+                                        ",".join(availDrvs))
             else:
                 if not value in getInstalledVideo(prefix="/") and \
-                    not value in ("auto",self.default_video):
-                    error =_("video driver %s is unavailable")%value
+                        not value in ("auto", self.default_video):
+                    error = _("video driver %s is unavailable") % value
                     if value in self.pkgDrvMap:
                         error += ". " + (_("Install driver %s with:")
-                                            %self.pkgDrvMap[value][0])
-                        error += "\n" + ("emerge %s"%self.pkgDrvMap[value][1])
+                                         % self.pkgDrvMap[value][0])
+                        error += "\n" + ("emerge %s" % self.pkgDrvMap[value][1])
                     raise VariableError(error)
         else:
-            availDrivers = self.Get('os_x11_kms_video_drv') + [self.default_video]
+            availDrivers = self.Get('os_x11_kms_video_drv') + [
+                self.default_video]
             if not value in availDrivers:
                 raise VariableError("Only %s drivers are available" %
                                     ",".join(availDrivers))
@@ -234,6 +243,7 @@ class VariableOsInstallX11VideoDrv(VideoVariable):
                 _("Video configuration unavailable for Flash install")
         return ""
 
+
 class VariableHrVideoId(ReadonlyVariable):
     """
     BusID of video card
@@ -241,6 +251,7 @@ class VariableHrVideoId(ReadonlyVariable):
     """
     value = ""
 
+
 class VariableOsInstallX11Composite(VideoVariable):
     """
     on/off composite
@@ -254,15 +265,15 @@ class VariableOsInstallX11Composite(VideoVariable):
 
     def get(self):
         """On/off composite"""
-        defaultCompositeOn = ("nvidia","intel","fglrx",
-            "nouveau","radeon", "default")
-        composite = getValueFromCmdLine("calculate",5)
-        videodrv = getValueFromCmdLine("calculate",4)
+        defaultCompositeOn = ("nvidia", "intel", "fglrx",
+                              "nouveau", "radeon", "default")
+        composite = getValueFromCmdLine("calculate", 5)
+        videodrv = getValueFromCmdLine("calculate", 4)
         if videodrv != "auto":
-            composite = {'nocomposite':'off',
-                         'off':'off',
-                         'on':'on',
-                         'composite':'on'}.get(composite)
+            composite = {'nocomposite': 'off',
+                         'off': 'off',
+                         'on': 'on',
+                         'composite': 'on'}.get(composite)
         else:
             composite = None
 
@@ -278,6 +289,7 @@ class VariableOsInstallX11Composite(VideoVariable):
             state = None
         return composite or state or defaultComposite
 
+
 class VariableOsInstallFbResolution(ResolutionVariable):
     """
     Framebuffer resolution
@@ -297,10 +309,10 @@ class VariableOsInstallFbResolution(ResolutionVariable):
     def get(self):
         """Get current framebuffer resolution"""
         try:
-            fbdev = os.open('/dev/fb0',os.O_RDONLY)
-            data = fcntl.ioctl(fbdev, self.FBIOGET_VSCREENINFO, " "*8)
-            res = struct.unpack("II",data)
-            return "%sx%s"%(res[0],res[1])
-        except (IOError,OSError):
+            fbdev = os.open('/dev/fb0', os.O_RDONLY)
+            data = fcntl.ioctl(fbdev, self.FBIOGET_VSCREENINFO, " " * 8)
+            res = struct.unpack("II", data)
+            return "%sx%s" % (res[0], res[1])
+        except (IOError, OSError):
             pass
         return "1024x768"
