@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2008-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -17,7 +17,8 @@
 import sys
 import re
 from calculate.lib.datavars import (Variable, ReadonlyVariable,
-                                    ReadonlyTableVariable, FieldValue)
+                                    ReadonlyTableVariable, FieldValue,
+                                    HumanReadable)
 from calculate.lib.utils.files import readFile
 
 from calculate.lib.cl_lang import setLocalTranslate, _
@@ -32,7 +33,7 @@ class VariableOsAudioData(ReadonlyTableVariable):
     source = ['os_audio_id',
               'os_audio_name']
 
-    def get(self, hr=False):
+    def get(self, hr=HumanReadable.No):
         data = readFile('/proc/asound/cards')
         cards = re.findall('^\s*(\d+).*\n\s+(\S.*) at .*$', data, re.M)
         if cards:
@@ -42,7 +43,8 @@ class VariableOsAudioData(ReadonlyTableVariable):
 
     setValue = Variable.setValue
 
-class VariableOsAudioId(FieldValue,ReadonlyVariable):
+
+class VariableOsAudioId(FieldValue, ReadonlyVariable):
     """
     Order Id of audio card
     """
@@ -50,7 +52,8 @@ class VariableOsAudioId(FieldValue,ReadonlyVariable):
     source_variable = "os_audio_data"
     column = 0
 
-class VariableOsAudioName(FieldValue,ReadonlyVariable):
+
+class VariableOsAudioName(FieldValue, ReadonlyVariable):
     """
     Name of audio card
     """
@@ -58,6 +61,7 @@ class VariableOsAudioName(FieldValue,ReadonlyVariable):
     source_variable = "os_audio_data"
     column = 1
 
+
 class VariableOsAudioDefaultSet(ReadonlyVariable):
     """
     Force write in config 0
@@ -69,11 +73,12 @@ class VariableOsAudioDefaultSet(ReadonlyVariable):
                           notlike='HDMI', limit=1)
         audio_default = self.Get('os_audio_default')
         if (audio_default != '0' or
-                res and res != "0" and audio_default == '0' or
-                audio_default != self.Get('os_audio_current')):
+                        res and res != "0" and audio_default == '0' or
+                    audio_default != self.Get('os_audio_current')):
             return 'on'
         return 'off'
 
+
 class VariableOsAudioCurrent(ReadonlyVariable):
     """
     Current default audio card
@@ -84,10 +89,11 @@ class VariableOsAudioCurrent(ReadonlyVariable):
         entry = default_card_re.search(readFile('/etc/asound.conf'))
         if entry and entry.groups()[0] in self.Get('os_audio_id'):
             return entry.groups()[0]
-        res = self.Select('os_audio_id',where='os_audio_name',
-                          notlike='HDMI',limit=1)
+        res = self.Select('os_audio_id', where='os_audio_name',
+                          notlike='HDMI', limit=1)
         return res or '0'
 
+
 class VariableOsAudioDefault(Variable):
     """
     Current default audio card
