@@ -699,7 +699,7 @@ class VariableOsBindPath(ReadonlyVariable):
     def get(self):
         fstab = FStab('/etc/fstab', devs=self.Get('os_disk_dev'))
         return fstab.getBy(what=fstab.NAME, where=fstab.OPTS,
-                           _in="bind", allentry=True)
+                           contains="bind", allentry=True)
 
 
 class VariableOsBindMountpoint(ReadonlyVariable):
@@ -711,7 +711,7 @@ class VariableOsBindMountpoint(ReadonlyVariable):
     def get(self):
         fstab = FStab('/etc/fstab', devs=self.Get('os_disk_dev'))
         return fstab.getBy(what=fstab.DIR, where=fstab.OPTS,
-                           _in="bind", allentry=True)
+                           contains="bind", allentry=True)
 
 
 ######################################################################
